@@ -39,7 +39,7 @@ async def load_socket_info(hub):
     except socket.gaierror:
         pass
 
-    if "fqdn" not in hub.corn.CORN:
+    if not hub.corn.CORN.get("fqdn"):
         hub.corn.CORN.fqdn = socket.getfqdn() or "localhost"
 
     log.debug("loading fqdns based grains")
