@@ -1,11 +1,17 @@
 # Build the osarch grain. This grain will be used for platform-specific
 # considerations such as package management. Fall back to the CPU architecture.
+import os
 import shutil
 
 
 async def get_osarch(hub):
-    if shutil.which("rpm"):
-        ret = await hub.exec.cmd.run('rpm --eval "${_host_cpu}"')
+    if shutil.which("uname"):
+        ret = await hub.exec.cmd.run(["uname", "-m"])
+        hub.corn.CORN.osarch = ret["stdout"].strip()
+    elif shutil.which("rpm") and os.environ.get("_host_cpu"):
+        ret = await hub.exec.cmd.run(
+            ["rpm", "--eval", os.environ["_host_cpu"]], shell=True
+        )
         hub.corn.CORN.osarch = ret["stdout"].strip() or "unknown"
     elif shutil.which("opkg"):
         archinfo = {}
@@ -22,9 +28,8 @@ async def get_osarch(hub):
             "stdout"
         ].strip()
     else:
-        try:
-            import platform
-
-            hub.corn.CORN.osarch = "".join([x for x in platform.uname()[-2:] if x][-1:])
-        except (ImportError, NameError):
-            hub.corn.CORN.osarch = hub.corn.CORN.cpuarch
+        # WOW64 processes mask the native architecture
+        if "PROCESSOR_ARCHITEW6432" in os.environ:
+            hub.corn.CORN.osarch = os.environ.get("PROCESSOR_ARCHITEW6432", "")
+        else:
+            hub.corn.CORN.osarch = os.environ.get("PROCESSOR_ARCHITECTURE", "")
